@@ -1,4 +1,4 @@
-__version__ = '1.4.3'
+__version__ = '1.4.3.1'
 __description__ = 'Comprehensive Knowledge Archive Network (CKAN) Software'
 __long_description__ = \
 '''The CKAN software is used to run the Comprehensive Knowledge Archive
@@ -16,11 +16,4 @@ analogous service for open knowledge.
 __license__ = 'AGPL'
 
 # The packaging system replies on this import, please do not remove it
-try:
-    # Ths automatically modifies sys.path so that the CKAN versions of
-    # key dependencies are used instead of the ones already installed.
-    import ckan_deps
-except ImportError:
-    # This installation of CKAN probably isn't using the ckan_deps
-    pass
-
+import sys; sys.path.insert(0, __path__[0])
