@@ -1,6 +1,7 @@
 """Pylons environment configuration"""
 import os
 from urlparse import urlparse
+import logging
 
 from paste.deploy.converters import asbool
 
@@ -88,6 +89,11 @@ def load_environment(global_conf, app_conf):
     def template_loaded(template):
         translator.setup(template)
 
+    # Markdown ignores the logger config, so to get rid of excessive
+    # markdown debug messages in the log, set it to the level of the
+    # root logger.
+    logging.getLogger("MARKDOWN").setLevel(logging.getLogger().level)
+
     # Create the Genshi TemplateLoader
     # config['pylons.app_globals'].genshi_loader = TemplateLoader(
     #    paths['templates'], auto_reload=True)
@@ -99,7 +105,7 @@ def load_environment(global_conf, app_conf):
     # any Pylons config options)    
 
     # Setup the SQLAlchemy database engine
-    engine = engine_from_config(config, 'sqlalchemy.', pool_threadlocal=True)
+    engine = engine_from_config(config, 'sqlalchemy.')
 
     if not model.meta.engine:
         model.init_model(engine)
