@@ -5,6 +5,9 @@
 Consists of functions to typically be used within templates, but also
 available to Controllers. This module is available to templates as 'h'.
 """
+import datetime
+import re
+
 from webhelpers.html import escape, HTML, literal, url_escape
 from webhelpers.html.tools import mail_to
 from webhelpers.html.tags import *
@@ -27,7 +30,7 @@ try:
     import json
 except ImportError:
     import simplejson as json
-
+    
 
 class Message(object):
     """A message returned by ``Flash.pop_messages()``.
@@ -202,10 +205,39 @@ class Page(paginate.Page):
 
 
 def render_datetime(datetime_):
-    '''Render a datetime object as a string in a reasonable way (Y-m-d H:m).
+    '''Render a datetime object or timestamp string as a pretty string
+    (Y-m-d H:m).
+    If timestamp is badly formatted, then a blank string is returned.
     '''
-    if datetime_:
-        return datetime_.strftime('%Y-%m-%d %H:%M')
+    from ckan import model
+    date_format = '%Y-%m-%d %H:%M'
+    if isinstance(datetime_, datetime.datetime):
+        return datetime_.strftime(date_format)
+    elif isinstance(datetime_, basestring):
+        try:
+            datetime_ = date_str_to_datetime(datetime_)
+        except TypeError:
+            return ''
+        except ValueError:
+            return ''
+        return datetime_.strftime(date_format)
     else:
         return ''
 
+def datetime_to_date_str(datetime_):
+    '''Takes a datetime.datetime object and returns a string of it
+    in ISO format.
+    '''
+    return datetime_.isoformat()
+
+def date_str_to_datetime(date_str):
+    '''Takes an ISO format timestamp and returns the equivalent
+    datetime.datetime object.
+    '''
+    # Doing this split is more accepting of input variations than doing
+    # a strptime. Also avoids problem with Python 2.5 not having %f.
+    return datetime.datetime(*map(int, re.split('[^\d]', date_str)))
+
+def time_ago_in_words_from_str(date_str, granularity='month'):
+    return date.time_ago_in_words(date_str_to_datetime(date_str), granularity=granularity)
+
