@@ -20,7 +20,13 @@ from ckan.logic.validators import (package_id_not_changed,
                                    duplicate_extras_key,
                                    ignore_not_admin,
                                    no_http,
-                                   tag_not_uppercase)
+                                   tag_not_uppercase,
+                                   user_name_validator,
+                                   user_password_validator,
+                                   user_both_passwords_entered,
+                                   user_passwords_match,
+                                   user_password_not_empty,
+                                   user_about_validator)
 from formencode.validators import OneOf
 import ckan.model
 
@@ -44,6 +50,10 @@ def default_resource_schema():
 
     return schema
 
+def default_update_resource_schema():
+    schema = default_resource_schema()
+    return schema
+
 def default_tags_schema():
 
     schema = {
@@ -185,4 +195,44 @@ def default_relationship_schema():
          'state': [ignore],
      }
 
+def default_user_schema():
+
+    schema = {
+        'id': [ignore_missing, unicode],
+        'name': [not_empty, unicode, user_name_validator],
+        'fullname': [ignore_missing, unicode],
+        'password': [user_password_validator, user_password_not_empty, ignore_missing, unicode],
+        'email': [ignore_missing, unicode],
+        'about': [ignore_missing, user_about_validator, unicode],
+        'created': [ignore],
+        'openid': [ignore],
+        'apikey': [ignore],
+        'reset_key': [ignore],
+    }
+    return schema
+
+def user_new_form_schema():
+    schema = default_user_schema()
+    
+    schema['password1'] = [unicode,user_both_passwords_entered,user_password_validator,user_passwords_match]
+    schema['password2'] = [unicode]
+
+    return schema
+
+def user_edit_form_schema():
+    schema = default_user_schema()
+
+    schema['name'] = [ignore_missing]
+    schema['password'] = [ignore_missing]
+    schema['password1'] = [ignore_missing,unicode,user_password_validator,user_passwords_match]
+    schema['password2'] = [ignore_missing,unicode]
+
+    return schema
+
+def default_update_user_schema():
+    schema = default_user_schema()
+    
+    schema['name'] = [ignore_missing]
+    schema['password'] = [user_password_validator,ignore_missing, unicode]
+    return schema
 
