@@ -179,6 +179,7 @@ class PackageSearchApiTestCase(ApiTestCase, ControllerTestCase):
     def test_08_uri_qjson_malformed(self):
         offset = self.base_url + '?qjson="q":""' # user forgot the curly braces
         res = self.app.get(offset, status=400)
+        self.assert_json_response(res, 'Bad request - Could not read parameters')
         
     def test_08_all_fields(self):
         rating = model.Rating(user_ip_address=u'123.1.2.3',
@@ -206,6 +207,13 @@ class PackageSearchApiTestCase(ApiTestCase, ControllerTestCase):
         assert anna_rec['ratings_average'] == 3.0, anna_rec['ratings_average']
         assert anna_rec['ratings_count'] == 1, anna_rec['ratings_count']
 
+    def test_08_all_fields_syntax_error(self):
+        offset = self.base_url + '?all_fields=should_be_boolean' # invalid all_fields value
+        res = self.app.get(offset, status=400)
+        assert('boolean' in res.body)
+        assert('all_fields' in res.body)
+        self.assert_json_response(res, 'boolean')
+
     def test_09_just_tags(self):
         offset = self.base_url + '?tags=russian&all_fields=1'
         res = self.app.get(offset, status=200)
@@ -251,6 +259,7 @@ class PackageSearchApiTestCase(ApiTestCase, ControllerTestCase):
         res = self.app.get(offset, status=400)
         assert('integer' in res.body)
         assert('offset' in res.body)
+        self.assert_json_response(res, 'integer')
 
     def test_12_all_packages_qjson(self):
         query = {'q': ''}
