@@ -1,6 +1,7 @@
 from routes import url_for
 from nose.tools import assert_equal
 
+from pprint import pprint
 from ckan.tests import search_related, CreateTestData
 from ckan.tests.html_check import HtmlCheckMethods
 from ckan.tests.pylons_controller import PylonsTestCase
@@ -61,6 +62,10 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         offset = '/user/'
         res = self.app.get(offset, status=302)
 
+    def test_user_read_me_without_id(self):
+        offset = '/user/me'
+        res = self.app.get(offset, status=302)
+
     def test_user_read_without_id_but_logged_in(self):
         user = model.User.by_name(u'annafan')
         offset = '/user/'
@@ -120,11 +125,12 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         assert 'spamsite2' not in res, res
         assert 'Error: Could not parse About text' in res, res
         
-    def test_user_login(self):
+    def test_user_login_page(self):
         offset = url_for(controller='user', action='login', id=None)
         res = self.app.get(offset, status=200)
         assert 'Login' in res, res
         assert 'Please click your account provider' in res, res
+        assert 'Forgot your password?' in res, res
         assert 'Don\'t have an OpenID' in res, res
 
     def test_logout(self):
@@ -132,19 +138,90 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         res2 = res.follow()
         assert 'You have logged out successfully.' in res2, res2
 
-    #def test_user_created_on_login(self):
-    #    username = u'okfntest'
-    #    user = model.User.by_name(username)
-    #    if user:
-    #        user.purge()
-    #        model.Session.commit()
-    #        model.Session.remove()
+    def _get_cookie_headers(self, res):
+        # For a request response, returns the Set-Cookie header values.
+        cookie_headers = []
+        for key, value in res.headers:
+            if key == 'Set-Cookie':
+                cookie_headers.append(value)
+        return cookie_headers
+        
+    def test_login(self):
+        # create test user
+        username = u'testlogin'
+        password = u'letmein'
+        CreateTestData.create_user(name=username,
+                                   password=password)
+        user = model.User.by_name(username)
+
+        # do the login
+        offset = url_for(controller='user', action='login')
+        res = self.app.get(offset)
+        fv = res.forms['login']
+        fv['login'] = username
+        fv['password'] = password
+        res = fv.submit()
+
+        # check cookies set
+        cookies = self._get_cookie_headers(res)
+        assert cookies
+        
+        # first get redirected to user/logged_in
+        assert_equal(res.status, 302)
+        assert res.header('Location').startswith('http://localhost/user/logged_in')
+
+        # then get redirected to user page
+        res = res.follow()
+        assert_equal(res.status, 302)
+        assert_equal(res.header('Location'), 'http://localhost/user/testlogin')
+        res = res.follow()
+        assert_equal(res.status, 200)
+        assert 'Welcome back, testlogin' in res.body
+        assert 'My Account' in res.body
+        
+        # check user object created
+        user = model.User.by_name(username)
+        assert user
+        assert_equal(user.name, username)
+        assert len(user.apikey) == 36
+
+        # check cookie created
+        cookie = res.request.environ['HTTP_COOKIE']
+        # I think some versions of webob do not produce quotes, hence the 'or'
+        assert 'ckan_display_name="testlogin"' in cookie or \
+               'ckan_display_name=testlogin' in cookie, cookie
+        assert 'auth_tkt=' in cookie, cookie
+        assert 'testlogin!userid_type:unicode' in cookie, cookie
+
+    def test_login_wrong_password(self):
+        # create test user
+        username = u'testloginwrong'
+        password = u'letmein'
+        CreateTestData.create_user(name=username,
+                                   password=password)
+        user = model.User.by_name(username)
+
+        # do the login
+        offset = url_for(controller='user', action='login')
+        res = self.app.get(offset)
+        fv = res.forms['login']
+        fv['login'] = username
+        fv['password'] = 'wrong_password'
+        res = fv.submit()
+
+        # first get redirected to logged_in
+        assert_equal(res.status, 302)
+        assert res.header('Location').startswith('http://localhost/user/logged_in')
+
+        # then get redirected to login
+        res = res.follow()
+        assert_equal(res.status, 302)
+        assert res.header('Location').startswith('http://localhost/user/login')
+        res = res.follow()
+        assert_equal(res.status, 200)
+        assert 'Login failed. Bad username or password.' in res.body
+        assert 'Login:' in res.body
 
-    #    offset = url_for(controller='user', action='login')
-    #    res = self.app.get(offset, extra_environ=dict(REMOTE_USER='okfntest'))
-    #    user = model.User.by_name(u'okfntest')
-    #    assert user
-    #    assert len(user.apikey) == 36
 
     # -----------
     # tests for top links present in every page
@@ -186,17 +263,18 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         fullname = u'Test Create'
         password = u'testpassword'
         assert not model.User.by_name(unicode(username))
+        rev_id_before_test = model.repo.youngest_revision().id
 
         offset = url_for(controller='user', action='register')
         res = self.app.get(offset, status=200)
         main_res = self.main_div(res)
         assert 'Register' in main_res, main_res
-        fv = res.forms['register_form']
-        fv['login'] = username
+        fv = res.forms['user-edit']
+        fv['name'] = username
         fv['fullname'] = fullname
         fv['password1'] = password
         fv['password2'] = password
-        res = fv.submit('signup')
+        res = fv.submit('save')
         
         # view user
         assert res.status == 302, self.main_div(res).encode('utf8')
@@ -209,14 +287,27 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
             res = res.follow()
         assert res.status == 200, res
         main_res = self.main_div(res)
-        assert username in main_res, main_res
         assert fullname in main_res, main_res
 
+        # check saved user object
         user = model.User.by_name(unicode(username))
         assert user
         assert_equal(user.name, username)
         assert_equal(user.fullname, fullname)
         assert user.password
+        
+        # no revision should be created - User is not revisioned
+        rev_id_after_test = model.repo.youngest_revision().id
+        assert_equal(rev_id_before_test, rev_id_after_test)
+
+        # check cookies created
+        cookie = res.request.environ['HTTP_COOKIE']
+        # I think some versions of webob do not produce quotes, hence the 'or'
+        assert 'ckan_display_name="Test Create"' in cookie or\
+               'ckan_display_name=Test Create' in cookie, cookie
+        assert 'auth_tkt=' in cookie, cookie
+        assert 'testcreate!userid_type:unicode' in cookie, cookie
+
 
     def test_user_create_unicode(self):
         # create/register user
@@ -229,12 +320,12 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         res = self.app.get(offset, status=200)
         main_res = self.main_div(res)
         assert 'Register' in main_res, main_res
-        fv = res.forms['register_form']
-        fv['login'] = username
+        fv = res.forms['user-edit']
+        fv['name'] = username
         fv['fullname'] = fullname.encode('utf8')
         fv['password1'] = password.encode('utf8')
         fv['password2'] = password.encode('utf8')
-        res = fv.submit('signup')
+        res = fv.submit('save')
         
         # view user
         assert res.status == 302, self.main_div(res).encode('utf8')
@@ -247,7 +338,6 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
             res = res.follow()
         assert res.status == 200, res
         main_res = self.main_div(res)
-        assert username in main_res, main_res
         assert fullname in main_res, main_res
 
         user = model.User.by_name(unicode(username))
@@ -264,13 +354,13 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         res = self.app.get(offset, status=200)
         main_res = self.main_div(res)
         assert 'Register' in main_res, main_res
-        fv = res.forms['register_form']
+        fv = res.forms['user-edit']
         fv['password1'] = password
         fv['password2'] = password
-        res = fv.submit('signup')
+        res = fv.submit('save')
         assert res.status == 200, res
         main_res = self.main_div(res)
-        assert 'Please enter a login name' in main_res, main_res
+        assert 'Name: Missing value' in main_res, main_res
 
     def test_user_create_bad_name(self):
         # create/register user
@@ -281,15 +371,15 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         res = self.app.get(offset, status=200)
         main_res = self.main_div(res)
         assert 'Register' in main_res, main_res
-        fv = res.forms['register_form']
-        fv['login'] = username
+        fv = res.forms['user-edit']
+        fv['name'] = username
         fv['password1'] = password
         fv['password2'] = password
-        res = fv.submit('signup')
+        res = fv.submit('save')
         assert res.status == 200, res
         main_res = self.main_div(res)
         assert 'login name is not valid' in main_res, main_res
-        self.check_named_element(main_res, 'input', 'name="login"', 'value="%s"' % username)
+        self.check_named_element(main_res, 'input', 'name="name"', 'value="%s"' % username)
 
     def test_user_create_bad_password(self):
         # create/register user
@@ -300,15 +390,15 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         res = self.app.get(offset, status=200)
         main_res = self.main_div(res)
         assert 'Register' in main_res, main_res
-        fv = res.forms['register_form']
-        fv['login'] = username
+        fv = res.forms['user-edit']
+        fv['name'] = username
         fv['password1'] = password
         fv['password2'] = password
-        res = fv.submit('signup')
+        res = fv.submit('save')
         assert res.status == 200, res
         main_res = self.main_div(res)
         assert 'password must be 4 characters or longer' in main_res, main_res
-        self.check_named_element(main_res, 'input', 'name="login"', 'value="%s"' % username)
+        self.check_named_element(main_res, 'input', 'name="name"', 'value="%s"' % username)
 
     def test_user_create_without_password(self):
         # create/register user
@@ -319,14 +409,54 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         res = self.app.get(offset, status=200)
         main_res = self.main_div(res)
         assert 'Register' in main_res, main_res
-        fv = res.forms['register_form']
-        fv['login'] = username
+        fv = res.forms['user-edit']
+        fv['name'] = username
         # no password
-        res = fv.submit('signup')
+        res = fv.submit('save')
         assert res.status == 200, res
         main_res = self.main_div(res)
-        assert 'Please enter a password' in main_res, main_res
-        self.check_named_element(main_res, 'input', 'name="login"', 'value="%s"' % username)
+        assert 'Password: Please enter both passwords' in main_res, main_res
+        self.check_named_element(main_res, 'input', 'name="name"', 'value="%s"' % username)
+
+    def test_user_create_only_one_password(self):
+        # create/register user
+        username = 'testcreate4'
+        password = u'testpassword'
+        user = model.User.by_name(unicode(username))
+
+        offset = url_for(controller='user', action='register')
+        res = self.app.get(offset, status=200)
+        main_res = self.main_div(res)
+        assert 'Register' in main_res, main_res
+        fv = res.forms['user-edit']
+        fv['name'] = username
+        fv['password1'] = password
+        # Only password1
+        res = fv.submit('save')
+        assert res.status == 200, res
+        main_res = self.main_div(res)
+        assert 'Password: Please enter both passwords' in main_res, main_res
+        self.check_named_element(main_res, 'input', 'name="name"', 'value="%s"' % username)
+
+    def test_user_invalid_password(self):
+        # create/register user
+        username = 'testcreate4'
+        password = u'tes' # Too short
+        user = model.User.by_name(unicode(username))
+
+        offset = url_for(controller='user', action='register')
+        res = self.app.get(offset, status=200)
+        main_res = self.main_div(res)
+        assert 'Register' in main_res, main_res
+        fv = res.forms['user-edit']
+        fv['name'] = username
+        fv['password1'] = password
+        fv['password2'] = password
+        res = fv.submit('save')
+        assert res.status == 200, res
+        main_res = self.main_div(res)
+        assert 'Password: Your password must be 4 characters or longer' in main_res, main_res
+        self.check_named_element(main_res, 'input', 'name="name"', 'value="%s"' % username)
 
     def test_user_edit(self):
         # create user
@@ -338,6 +468,7 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
                                          password='letmein'))
             model.repo.commit_and_remove()
             user = model.User.by_name(unicode(username))
+        rev_id_before_test = model.repo.youngest_revision().id
 
         # edit
         new_about = u'Changed about'
@@ -356,8 +487,6 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         # preview
         main_res = self.main_div(res)
         assert 'Edit User: testedit' in main_res, main_res
-        before_preview = main_res[:main_res.find('Preview')]
-        assert new_about in before_preview, before_preview
         in_preview = main_res[main_res.find('Preview'):]
         assert new_about in in_preview, in_preview
 
@@ -375,6 +504,87 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         main_res = self.main_div(res)
         assert new_about in main_res, main_res
 
+        # no revision should be created - User is not revisioned
+        rev_id_after_test = model.repo.youngest_revision().id
+        assert_equal(rev_id_before_test, rev_id_after_test)
+
+    def test_user_edit_no_password(self):
+        # create user
+        username = 'testedit2'
+        about = u'Test About'
+        user = model.User.by_name(unicode(username))
+        if not user:
+            model.Session.add(model.User(name=unicode(username), about=about,
+                                         password='letmein'))
+            model.repo.commit_and_remove()
+            user = model.User.by_name(unicode(username))
+
+        old_password = user.password    
+
+        # edit
+        new_about = u'Changed about'
+        offset = url_for(controller='user', action='edit', id=user.id)
+        res = self.app.get(offset, status=200, extra_environ={'REMOTE_USER':username})
+        main_res = self.main_div(res)
+        assert 'Edit User: ' in main_res, main_res
+        assert about in main_res, main_res
+        fv = res.forms['user-edit']
+        fv['about'] = new_about
+        fv['password1'] = ''
+        fv['password2'] = ''
+
+        res = fv.submit('preview', extra_environ={'REMOTE_USER':username})
+        
+        # preview
+        main_res = self.main_div(res)
+        assert 'Edit User: testedit2' in main_res, main_res
+        in_preview = main_res[main_res.find('Preview'):]
+        assert new_about in in_preview, in_preview
+
+        # commit
+        res = fv.submit('save', extra_environ={'REMOTE_USER':username})      
+        assert res.status == 302, self.main_div(res).encode('utf8')
+        res = res.follow()
+        main_res = self.main_div(res)
+        assert 'testedit2' in main_res, main_res
+        assert new_about in main_res, main_res
+
+        # read, not logged in
+        offset = url_for(controller='user', action='read', id=user.id)
+        res = self.app.get(offset, status=200)
+        main_res = self.main_div(res)
+        assert new_about in main_res, main_res
+
+        updated_user = model.User.by_name(unicode(username))
+        new_password = updated_user.password
+
+        # Ensure password has not changed
+        assert old_password == new_password
+
+    def test_user_edit_no_user(self):
+        offset = url_for(controller='user', action='edit', id=None)
+        res = self.app.get(offset, status=400)
+        assert 'No user specified' in res, res
+
+    def test_user_edit_unknown_user(self):
+        offset = url_for(controller='user', action='edit', id='unknown_person')
+        res = self.app.get(offset, status=404)
+        assert 'User not found' in res, res
+
+    def test_user_edit_not_logged_in(self):
+        # create user
+        username = 'testedit'
+        about = u'Test About'
+        user = model.User.by_name(unicode(username))
+        if not user:
+            model.Session.add(model.User(name=unicode(username), about=about,
+                                         password='letmein'))
+            model.repo.commit_and_remove()
+            user = model.User.by_name(unicode(username))
+
+        offset = url_for(controller='user', action='edit', id=username)
+        res = self.app.get(offset, status=302)
+
     def test_edit_spammer(self):
         # create user
         username = 'testeditspam'
@@ -401,34 +611,12 @@ class TestUserController(FunctionalTestCase, HtmlCheckMethods, PylonsTestCase, S
         assert 'looks like spam' in main_res, main_res
         assert 'Edit User: ' in main_res, main_res
 
-
-    ############
-    # Disabled
-    ############
-
-    # TODO: 2009-06-27 delete/update these methods (now moving to repoze)
-    def _login_form(self, res):
-        # cannot use for time being due to 'bug' in AuthKit
-        # paste.fixture does not set REMOTE_ADDR which AuthKit requires to do
-        # its stuff (though note comment in code suggesting amendment)
-        # create cookie see authkit/authenticate/cookie.py l. 364 
-            # if self.include_ip:
-            # # Fixes ticket #30
-            # # @@@ should this use environ.get('REMOTE_ADDR','0.0.0.0')?
-            #  remote_addr = environ.get('HTTP_X_FORWARDED_FOR', environ['REMOTE_ADDR'])
-            #  
-            # KeyError: 'REMOTE_ADDR' 
-        # could get round this by adding stuff to environ using paste fixture's
-        # extra_environ, see:
-        # http://pythonpaste.org/webtest/#modifying-the-environment-simulating-authentication
-        assert 'Please Sign In' in res
-        username = u'okfntest'
-        password = u'okfntest'
-        fv = res.forms['user-login']
-        fv['username'] = username
-        fv['password'] = password
-        res = fv.submit()
-        return res
+    def test_login_openid_error(self):
+        # comes back as a params like this:
+        # e.g. /user/login?error=Error%20in%20discovery:%20Error%20fetching%20XRDS%20document:%20(6,%20%22Couldn't%20resolve%20host%20'mysite.myopenid.com'%22)
+        res = self.app.get("/user/login?error=Error%20in%20discovery:%20Error%20fetching%20XRDS%20document:%20(6,%20%22Couldn't%20resolve%20host%20'mysite.myopenid.com'%22")
+        main_res = self.main_div(res)
+        assert "Couldn't resolve host" in main_res, main_res
 
     def _login_openid(self, res):
         # this requires a valid account on some openid provider
