@@ -8,12 +8,18 @@ http://groups.google.com/group/pylons-discuss/browse_thread/thread/5f8d8f59fd459
 from unittest import TestCase 
 from paste.registry import Registry 
 import pylons 
-from pylons.util import ContextObj 
+from pylons.util import AttribSafeContextObj
+import ckan.lib.app_globals as app_globals
 from pylons.controllers.util import Request, Response 
+from routes.util import URLGenerator
 
+from ckan.config.routing import make_map
 from ckan.tests import *
 from ckan.lib.cli import MockTranslator
 
+class TestSession(dict):
+    def save(self):
+        pass
 
 class PylonsTestCase(object):
     """A basic test case which allows access to pylons.c and pylons.request. 
@@ -23,9 +29,11 @@ class PylonsTestCase(object):
         cls.registry=Registry() 
         cls.registry.prepare() 
 
-        cls.context_obj=ContextObj() 
+        cls.context_obj=AttribSafeContextObj()
         cls.registry.register(pylons.c, cls.context_obj)
-        pylons.c.errors = None
+
+        cls.app_globals_obj = app_globals.Globals()
+        cls.registry.register(pylons.g, cls.app_globals_obj)
 
         cls.request_obj=Request(dict(HTTP_HOST="nohost")) 
         cls.registry.register(pylons.request, cls.request_obj) 
@@ -37,4 +45,6 @@ class PylonsTestCase(object):
         cls.registry.register(pylons.buffet, cls.buffet)
 
         cls.registry.register(pylons.response, Response())
-        cls.registry.register(pylons.url, None)
+        mapper = make_map()
+        cls.registry.register(pylons.url, URLGenerator(mapper, {}))
+        cls.registry.register(pylons.session, TestSession())
